@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001-2009 Zope Corporation and Contributors.
+# Copyright (c) 2001-2009 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,15 +12,13 @@
 #
 ##############################################################################
 """Tests for the principal registry ZCML directives
-
-$Id: test_doc.py 98046 2009-03-13 20:12:47Z nadako $
 """
-import unittest
-from zope.testing import doctest
-from zope.component.testing import setUp as setUpComponent 
+from zope.component.testing import setUp as setUpComponent
 from zope.component.testing import tearDown as tearDownComponent
-from zope.configuration import xmlconfig 
+from zope.configuration import xmlconfig
 from zope.password.testing import setUpPasswordManagers
+import doctest
+import unittest
 
 def setUp(test=None):
     setUpComponent()
